@@ -50,16 +50,16 @@ my $generate_guid = sub ($self) {
 };
 
 my $recycle_guid = sub ($self) {
-    my $current = $self->{available};
+    my $next = $self->{available};
 
     die 'Cannot recycle GUID if none has been released'
-        if $current->$is_null;
+        if $next->$is_null;
 
-    my $version = $self->{entities}[$current] & ( VERSION_MASK << ENTITY_SHIFT );
+    my $ver = $self->{entities}[$next]->$version;
 
-    $self->{available} = $self->{entities}[$current]->$entity;
+    $self->{available} = $self->{entities}[$next]->$entity;
 
-    return $self->{entities}[$current] = $current | $version;
+    return $self->{entities}[$next] = $next | ( $ver << ENTITY_SHIFT );
 };
 
 my $get = sub ( $self, $unsafe, $guid, @types ) {
@@ -197,7 +197,7 @@ sub delete ( $self, $guid, @types ) {
 
         # We mark an entity as available by splitting the entity and the version
         # and storing the incremented version only in the entities list, and the
-        # available entity ID in $AVAILABLE
+        # available entity ID in the 'available' slot
 
         my $ent = $guid->$entity;
         my $ver = $guid->$version + 1;
